==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebGridRowEditTextTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridRowEditTextTemplateContextDescription } from "./WebGridRowEditTextTemplateContextDescription";
/**
 * @hidden
 */
var WebGridRowEditTextTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridRowEditTextTemplateContextDescriptionMetadata, _super);
    function WebGridRowEditTextTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridRowEditTextTemplateContextDescriptionMetadata.b = function (a) {
        if (WebGridRowEditTextTemplateContextDescriptionMetadata.a == null) {
            WebGridRowEditTextTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridRowEditTextTemplateContextDescriptionMetadata.c(WebGridRowEditTextTemplateContextDescriptionMetadata.a);
        }
        if (a.j(WebGridRowEditTextTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGridRowEditTextTemplateContextDescriptionMetadata.a);
    };
    WebGridRowEditTextTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridRowEditTextTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Implicit", "Number:double");
    };
    WebGridRowEditTextTemplateContextDescriptionMetadata.d = function (a) {
        WebGridRowEditTextTemplateContextDescriptionMetadata.b(a);
        a.aa("WebGridRowEditTextTemplateContext", function () { return new WebGridRowEditTextTemplateContextDescription(); });
        a.z("WebGridRowEditTextTemplateContext", WebGridRowEditTextTemplateContextDescriptionMetadata.a);
    };
    WebGridRowEditTextTemplateContextDescriptionMetadata.$t = markType(WebGridRowEditTextTemplateContextDescriptionMetadata, 'WebGridRowEditTextTemplateContextDescriptionMetadata');
    WebGridRowEditTextTemplateContextDescriptionMetadata.a = null;
    return WebGridRowEditTextTemplateContextDescriptionMetadata;
}(Base));
export { WebGridRowEditTextTemplateContextDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebGridRowEditTextTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridRowEditTextTemplateContextDescription } from "./WebGridRowEditTextTemplateContextDescription";
/**
 * @hidden
 */
var WebGridRowEditTextTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridRowEditTextTemplateContextDescriptionMetadata, _super);
    function WebGridRowEditTextTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridRowEditTextTemplateContextDescriptionMetadata.b = function (a) {
        if (WebGridRowEditTextTemplateContextDescriptionMetadata.a == null) {
            WebGridRowEditTextTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridRowEditTextTemplateContextDescriptionMetadata.c(WebGridRowEditTextTemplateContextDescriptionMetadata.a);
        }
        if (a.k(WebGridRowEditTextTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGridRowEditTextTemplateContextDescriptionMetadata.a);
    };
    WebGridRowEditTextTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridRowEditTextTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Implicit", "Number:double");
    };
    WebGridRowEditTextTemplateContextDescriptionMetadata.d = function (a) {
        WebGridRowEditTextTemplateContextDescriptionMetadata.b(a);
        a.ac("WebGridRowEditTextTemplateContext", function () { return new WebGridRowEditTextTemplateContextDescription(); });
        a.ab("WebGridRowEditTextTemplateContext", WebGridRowEditTextTemplateContextDescriptionMetadata.a);
    };
    WebGridRowEditTextTemplateContextDescriptionMetadata.$t = markType(WebGridRowEditTextTemplateContextDescriptionMetadata, 'WebGridRowEditTextTemplateContextDescriptionMetadata');
    WebGridRowEditTextTemplateContextDescriptionMetadata.a = null;
    return WebGridRowEditTextTemplateContextDescriptionMetadata;
}(Base));
export { WebGridRowEditTextTemplateContextDescriptionMetadata };
